﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using TeeChart;

namespace XaxisProblem
{
    class Program
    {
        static void Main(string[] args)
        {
            var tChart = new TChart();
            initial(tChart);

            var seriesDatas = getSeriesDatas();
            foreach (var seriesData in seriesDatas)
                addSeries(tChart, seriesData);

            var fileName = Path.Combine(Environment.CurrentDirectory, @"sample.png") ;
            tChart.Export.asPNG.SaveToFile(fileName);
        }

        static void initial(TChart tChart)
        {
            tChart.Environment.IEPrintWithPage = true;
            tChart.Frame.Visible = true;

            tChart.Aspect.Orthogonal = false;
            tChart.Aspect.Perspective = 35;
            tChart.Aspect.HorizOffset = -20;
            tChart.Aspect.View3D = false;

            tChart.Walls.Back.Color = 0;
            tChart.Walls.Back.Transparent = false;
            tChart.Walls.Back.Gradient.StartColor = 0;
            tChart.Walls.Back.Gradient.MidColor = 0;
            tChart.Walls.Back.Gradient.EndColor = 0;

            tChart.Legend.Alignment = (ELegendAlignment)3;
            tChart.Legend.TopPos = 0;
            tChart.Legend.Visible = false;

            tChart.Header.Text.Clear();
            tChart.Header.AdjustFrame = true;
            tChart.Header.Alignment = ETitleAlignment.taCenter;
            tChart.Header.Shadow.Visible = false;
            tChart.Header.Transparent = true;

            tChart.Axis.Left.Title.Angle = 90;
            tChart.Axis.Left.Labels.Style = EAxisLabelStyle.talValue;
            tChart.Axis.Left.StartPosition = 2;
            tChart.Axis.Left.EndPosition = 98;
            tChart.Axis.Bottom.Title.Angle = 0;
            tChart.Axis.Bottom.Labels.Style = EAxisLabelStyle.talText;
            tChart.Axis.Bottom.StartPosition = 2;
            tChart.Axis.Bottom.EndPosition = 98;
            tChart.Axis.Bottom.Labels.Angle = 270;
            tChart.Axis.Bottom.Labels.Separation = 10;

            tChart.Panel.Color = 0xFF0000;
            tChart.Panel.BevelWidth = 1;
            tChart.Panel.BevelInner = (EPanelBevel)2;
            tChart.Panel.BevelOuter = (EPanelBevel)1;
            tChart.Panel.Gradient.StartColor = 14544588;
            tChart.Panel.Gradient.MidColor = 14544588;
            tChart.Panel.Gradient.EndColor = 14544588;

            tChart.Footer.Text.Add(0);
            tChart.Footer.Font.Color = 0x0000ff;
            tChart.Footer.Text[0] = "WINBOND";
            tChart.Footer.Alignment = ETitleAlignment.taRightJustify;
        }

        static void addSeries(TChart tChart, SeriesModel series)
        {
            var iSeries = tChart.Series(tChart.AddSeries(ESeriesClass.scLine));
            iSeries.Title = series.ID;
            iSeries.Color = 0x00ff00;
            iSeries.Pen.Width = 1;

            foreach (var point in series.Points)
                iSeries.AddXY(point.X, point.Y, point.X.ToString(), iSeries.Color);
        }

        static List<SeriesModel> getSeriesDatas()
        {
            var dataFileName = Path.Combine(Environment.CurrentDirectory, "Datas.txt");

            return File.ReadAllLines(dataFileName)
                .Where((r, index) => index > 0) // ignore column name row
                .Select(r => r.Split('\t'))
                .Select(r => new
                {
                    SeriesID = r[0],
                    X = double.Parse(r[1]),
                    Y = double.Parse(r[2])
                })
                .GroupBy(r => r.SeriesID)
                .Select(r => new SeriesModel
                {
                    ID = r.Key,
                    Points = r.Select(s => new PointModel { X = s.X, Y = s.Y }).ToList()
                })
                .ToList();
        }

    }

    #region DataModel
    public class SeriesModel
    {
        public string ID { get; set; }
        public List<PointModel> Points { get; set; }
    }

    public class PointModel
    {
        public double X { get; set; }
        public double Y { get; set; }
    }
    #endregion //DataModel

}